@@ -3,7 +3,7 @@
  * 
  * This file is a part of NSIS.
  * 
- * Copyright (C) 1999-2008 Nullsoft and Contributors
+ * Copyright (C) 1999-2009 Nullsoft and Contributors
  * 
  * Licensed under the zlib/libpng license (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@
 #ifdef _WIN32
 #  include <windows.h>
 #  include <commctrl.h>
+#  include <shellapi.h>
 #else
 #  ifndef EXEHEAD
 #    include <string.h>
@@ -56,6 +57,7 @@ typedef unsigned int UINT_PTR;
 // basic stuff
 typedef void * HANDLE;
 typedef HANDLE HWND;
+typedef HANDLE HMODULE;
 typedef unsigned long HKEY;
 // some gdi
 typedef unsigned long COLORREF;
@@ -142,27 +144,6 @@ typedef DWORDLONG ULONGLONG,*PULONGLONG;
 #  endif
 #endif
 
-// Added by Dave Laundon 19th August 2002
-// For all internal functions, use of stdcall calling convention moves the
-// responsibility for tidying the stack to callee from caller, reducing the code
-// involved considerably.  Gives an instant saving of 0.5K.
-// NB - the zlib and bzip2 portions have been given the same treatment, but with
-// project compiler-options settings and/or project-wide defines.
-// NB - safer for NSIS's routines to be defined explicitly to avoid problems
-// calling DLL functions.
-#if defined(_WIN32) && ((_MSC_VER >= 800) || defined(_STDCALL_SUPPORTED))
-#  define NSISCALL  __stdcall   // Ordinary functions
-#  define NSISCALLV __cdecl     // Variable-argument-list functions
-#else
-#  if defined(__GNUC__) && defined(__i386__)
-#    define NSISCALL  __attribute__((__stdcall__))   // Ordinary functions
-#    define NSISCALLV __attribute__((__cdecl__))     // Variable-argument-list functions
-#  else
-#    define NSISCALL
-#    define NSISCALLV
-#  endif
-#endif
-
 #if defined(__GNUC__)
 #define UNUSED __attribute__((unused))
 #else
